@@ -21,6 +21,7 @@ class VideoItemWidget(QWidget, Ui_VideoItemWidget):
         """
         QWidget.__init__(self, parent)
         self.setupUi(self)
+        self.checkBox.mousePressEvent = self.ignoreClick
         self.titleLabel.setText(unicode(video.title.text,  "utf-8"))
         self.durationLabel.setText(unicode(time.strftime('%M:%S', time.gmtime(float(video.media.duration.seconds)))))
         self.authorLabel.setText(unicode(video.author[0].name.text, "utf-8"))
@@ -32,6 +33,12 @@ class VideoItemWidget(QWidget, Ui_VideoItemWidget):
             self.ratingLabel.setPixmap(QPixmap(":/images/ui-images/rating%s.png" % unicode(round(float(video.rating.average)))))
         except:
             self.ratingLabel.setPixmap(QPixmap(":/images/ui-images/rating3.0.png"))  
+            
+    def ignoreClick(self, event):
+        """
+        Propagates the mouse event to the parent.
+        """
+        event.ignore()
 
     def hideCheckBox(self):
         """
