@@ -8,7 +8,7 @@ from PyQt4.QtCore import *
 from PyQt4.QtMaemo5 import QMaemo5InformationBox
 from Ui_cutetubewindows import Ui_CutetubeWindows
 
-import videoinfowindow
+from videoinfowindow import VideoInfoWindow
 import customwidgets
 import youtubeservice
 import cutetubedialogs
@@ -217,6 +217,7 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         itemWidget = customwidgets.VideoItemWidget(videoData[0], videoData[1])
         if self.actionPencil.isChecked():
             itemWidget.showCheckBox()
+            item.setFlags(Qt.ItemIsEnabled)
         self.listWidget.addItem(item)
         self.listWidget.setItemWidget(item, itemWidget)
         title = itemWidget.titleLabel.text()
@@ -235,14 +236,11 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
             checkBox = self.listWidget.itemWidget(item).checkBox
             checkBox.toggle()
             if checkBox.isChecked():
-                try:
-                    self.pencilList.append(self.listWidget.row(item))
-                    self.actionPencilQueue.setVisible(True)
-                    self.actionPencilDownloads.setVisible(True)
-                    self.actionPencilPlaylist.setVisible(True)
-                    self.actionPencilFavourites.setVisible(True)
-                except Exception, e:
-                    CutetubeLog.logException(e.message)
+                self.pencilList.append(self.listWidget.row(item))
+                self.actionPencilQueue.setVisible(True)
+                self.actionPencilDownloads.setVisible(True)
+                self.actionPencilPlaylist.setVisible(True)
+                self.actionPencilFavourites.setVisible(True)
             else:
                 self.pencilList.remove(self.listWidget.row(item))
                 if len(self.pencilList) == 0:
@@ -253,7 +251,7 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         else:
             row = self.listWidget.row(item)
             video = self.yt.videoList[row]
-            videoInfoWindow = videoinfowindow.VideoInfoWindow(self, video)
+            videoInfoWindow = VideoInfoWindow(self, video)
             self.connect(videoInfoWindow, SIGNAL("queueChanged(int)"), self.queueChanged)
             self.connect(videoInfoWindow, SIGNAL("downloadsChanged(int)"), self.downloadsChanged)
             self.listWidget.setCurrentRow(-1)
@@ -520,6 +518,7 @@ class SearchResultsWindow(CutetubeWindows):
         itemWidget = customwidgets.VideoItemWidget(videoData[0], videoData[1])
         if self.actionPencil.isChecked():
             itemWidget.showCheckBox()
+            item.setFlags(Qt.ItemIsEnabled)
         self.listWidget.addItem(item)
         self.listWidget.setItemWidget(item, itemWidget)
         title = itemWidget.titleLabel.text()
@@ -880,7 +879,7 @@ class PlaylistVideosWindow(CutetubeWindows):
             playlistVideo = self.yt.videoList[row]
             position = row + 1
             count = len(self.yt.videoList)
-            videoInfoWindow = videoinfowindow.VideoInfoWindow(self, playlistVideo, playlistId, position, count)
+            videoInfoWindow = VideoInfoWindow(self, playlistVideo, playlistId, position, count)
             self.connect(videoInfoWindow, SIGNAL("queueChanged(int)"), self.queueChanged)
             self.connect(videoInfoWindow, SIGNAL("downloadsChanged(int)"), self.downloadsChanged)
             self.listWidget.setCurrentRow(-1)
@@ -941,8 +940,6 @@ class PlaybackQueueWindow(CutetubeWindows):
         item = QListWidgetItem()
         item.setSizeHint(size)
         itemWidget = customwidgets.VideoItemWidget(videoData[0], videoData[1])
-        if self.actionPencil.isChecked():
-            itemWidget.showCheckBox()
         self.listWidget.addItem(item)
         self.listWidget.setItemWidget(item, itemWidget)
         title = itemWidget.titleLabel.text()
@@ -1288,7 +1285,7 @@ class DownloadsWindow(CutetubeWindows):
         """
         row = self.listWidget.row(item)
         video = youtubeservice.YouTubeVideoDownloader.taskQueue[row].video
-        videoInfoWindow = videoinfowindow.VideoInfoWindow(self, video)
+        videoInfoWindow = VideoInfoWindow(self, video)
         self.connect(videoInfoWindow, SIGNAL("queueChanged(int)"), self.queueChanged)
         self.listWidget.setCurrentRow(-1)
         self.closeFilter()
