@@ -6,17 +6,15 @@ Module implementing HomeWindow.
 import os
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
-try:
-    from PyQt4.QtMaemo5 import QMaemo5InformationBox
-except:
-    pass
+from PyQt4.QtMaemo5 import QMaemo5InformationBox
 from Ui_homewindow import Ui_HomeWindow
-
 import myaccountwindow
 import cutetubedialogs
 import cutetubewindows
+from aboutwindow import AboutWindow
 from youtubeservice import YouTubeDataService, YouTubeVideoDownloader
 from cutetubeconfig import *
+from cutetubelog import CutetubeLog
 
 class HomeWindow(QMainWindow, Ui_HomeWindow):
     """
@@ -26,6 +24,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         """
         Constructor
         """
+        CutetubeLog.logInfo("Lanching cuteTube")
         QMainWindow.__init__(self, parent)
         self.setupUi(self)
         self.restoreSettings()
@@ -69,7 +68,9 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         Attempt to sign in using the default account details.
         """
         try:
+            CutetubeLog.logInfo("Looking for YouTube accounts")
             if YouTubeAPISettings.userDict == {}:
+                CutetubeLog.logInfo("No accounts found")
                 if YouTubeAPISettings.raiseNoAccountFoundDialog:
                     noAccountFoundDialog = cutetubedialogs.NoAccountFoundDialog(self)
             else:
@@ -104,63 +105,74 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         """
         Restores the application settings.
         """
-        settings = QSettings()
-        GeneralSettings.autoOrientation = settings.value("autoOrientation", True).toBool()
-        YouTubeAPISettings.userDict = settings.value("userDict",  {}).toPyObject()
-        YouTubeAPISettings.defaultUser = settings.value("defaultUser",  "").toString()
-        YouTubeAPISettings.raiseNoAccountFoundDialog = settings.value("noAccountDialog",  True).toBool()
-        if VideoPlaybackSettings.playbackFormat in (17, 18):
-            VideoPlaybackSettings.playbackFormat = settings.value("playbackFormat",  18).toInt()[0]
-        VideoDownloadSettings.downloadFolder = settings.value("downloadFolder",  "/home/user/MyDocs/.videos").toString()
-        VideoDownloadSettings.defaultTaskStatus = settings.value("downloadStatus",  "paused").toString()
-        if VideoDownloadSettings.downloadFormat in (17, 18, 34, 35, 22):
-            VideoDownloadSettings.downloadFormat = settings.value("downloadFormat",  18).toInt()[0]
-        YouTubeVideoDownloader.restoreTasks(settings.value("downloadTaskQueue", QStringList()).toStringList())
-        VideoSharingSettings.raiseTwitterAuthorisationDialog = settings.value("twitterAuthDialog", True).toBool()
-        VideoSharingSettings.twitterAccessTokenKey = settings.value("twitterKey", "").toString()
-        VideoSharingSettings.twitterAccessTokenSecret = settings.value("twitterSecret", "").toString()
-        VideoSharingSettings.raiseFacebookAuthorisationDialog = settings.value("facebookAuthDialog", True).toBool()
-        VideoSharingSettings.facebookAccessToken = settings.value("facebookToken", "").toString()
-        SearchSettings.searchOrder = settings.value("searchOrder",  0).toInt()[0]
-        SearchSettings.recentSearches = settings.value("recentSearches", QStringList()).toStringList()
+        CutetubeLog.logInfo("Restoring settings")
+        try:
+            settings = QSettings()
+            GeneralSettings.autoOrientation = settings.value("autoOrientation", True).toBool()
+            YouTubeAPISettings.userDict = settings.value("userDict",  {}).toPyObject()
+            YouTubeAPISettings.defaultUser = settings.value("defaultUser",  "").toString()
+            YouTubeAPISettings.raiseNoAccountFoundDialog = settings.value("noAccountDialog",  True).toBool()
+            if VideoPlaybackSettings.playbackFormat in (17, 18):
+                VideoPlaybackSettings.playbackFormat = settings.value("playbackFormat",  18).toInt()[0]
+            VideoDownloadSettings.downloadFolder = settings.value("downloadFolder",  "/home/user/MyDocs/.videos").toString()
+            VideoDownloadSettings.defaultTaskStatus = settings.value("downloadStatus",  "paused").toString()
+            if VideoDownloadSettings.downloadFormat in (17, 18, 34, 35, 22):
+                VideoDownloadSettings.downloadFormat = settings.value("downloadFormat",  18).toInt()[0]
+            YouTubeVideoDownloader.restoreTasks(settings.value("downloadTaskQueue", QStringList()).toStringList())
+            VideoSharingSettings.raiseTwitterAuthorisationDialog = settings.value("twitterAuthDialog", True).toBool()
+            VideoSharingSettings.twitterAccessTokenKey = settings.value("twitterKey", "").toString()
+            VideoSharingSettings.twitterAccessTokenSecret = settings.value("twitterSecret", "").toString()
+            VideoSharingSettings.raiseFacebookAuthorisationDialog = settings.value("facebookAuthDialog", True).toBool()
+            VideoSharingSettings.facebookAccessToken = settings.value("facebookToken", "").toString()
+            SearchSettings.searchOrder = settings.value("searchOrder",  0).toInt()[0]
+            SearchSettings.recentSearches = settings.value("recentSearches", QStringList()).toStringList()
+            CutetubeLog.logInfo("Settings restored successfully")
+        except Exception, e:
+            CutetubeLog.logException("Unable to restore settings:")
+            
         
     def closeEvent(self,  event):
         """
         Saves the application settings.
         """
-        settings = QSettings()
-        autoOrientation = QVariant(GeneralSettings.autoOrientation)
-        userDict = QVariant(YouTubeAPISettings.userDict)
-        defaultUser = QVariant(YouTubeAPISettings.defaultUser)
-        noAccountDialog = QVariant(YouTubeAPISettings.raiseNoAccountFoundDialog)
-        playbackFormat = QVariant(VideoPlaybackSettings.playbackFormat)        
-        downloadFolder = QVariant(VideoDownloadSettings.downloadFolder)
-        downloadStatus = QVariant(VideoDownloadSettings.defaultTaskStatus)
-        downloadFormat = QVariant(VideoDownloadSettings.downloadFormat)
-        downloadTaskQueue = QVariant (YouTubeVideoDownloader.saveTasks())
-        twitterAuthDialog = QVariant(VideoSharingSettings.raiseTwitterAuthorisationDialog)
-        twitterKey = QVariant(VideoSharingSettings.twitterAccessTokenKey)
-        twitterSecret = QVariant(VideoSharingSettings.twitterAccessTokenSecret)
-        facebookAuthDialog = QVariant(VideoSharingSettings.raiseFacebookAuthorisationDialog)
-        facebookToken = QVariant(VideoSharingSettings.facebookAccessToken)
-        searchOrder = QVariant(SearchSettings.searchOrder)
-        recentSearches = QVariant(SearchSettings.recentSearches)
-        settings.setValue("autoOrientation", autoOrientation)
-        settings.setValue("userDict", userDict)
-        settings.setValue("defaultUser", defaultUser)
-        settings.setValue("noAccountDialog", noAccountDialog)
-        settings.setValue("downloadFolder", downloadFolder)
-        settings.setValue("downloadStatus", downloadStatus)
-        settings.setValue("playbackFormat", playbackFormat)
-        settings.setValue("downloadFormat", downloadFormat)
-        settings.setValue("downloadTaskQueue", downloadTaskQueue)
-        settings.setValue("twitterAuthDialog", twitterAuthDialog)
-        settings.setValue("twitterKey", twitterKey)
-        settings.setValue("twitterSecret", twitterSecret)
-        settings.setValue("facebookAuthDialog", facebookAuthDialog)
-        settings.setValue("facebookToken", facebookToken)
-        settings.setValue("searchOrder", searchOrder)
-        settings.setValue("recentSearches", recentSearches)
+        try:
+            CutetubeLog.logInfo("Saving settings")
+            settings = QSettings()
+            autoOrientation = QVariant(GeneralSettings.autoOrientation)
+            userDict = QVariant(YouTubeAPISettings.userDict)
+            defaultUser = QVariant(YouTubeAPISettings.defaultUser)
+            noAccountDialog = QVariant(YouTubeAPISettings.raiseNoAccountFoundDialog)
+            playbackFormat = QVariant(VideoPlaybackSettings.playbackFormat)        
+            downloadFolder = QVariant(VideoDownloadSettings.downloadFolder)
+            downloadStatus = QVariant(VideoDownloadSettings.defaultTaskStatus)
+            downloadFormat = QVariant(VideoDownloadSettings.downloadFormat)
+            downloadTaskQueue = QVariant (YouTubeVideoDownloader.saveTasks())
+            twitterAuthDialog = QVariant(VideoSharingSettings.raiseTwitterAuthorisationDialog)
+            twitterKey = QVariant(VideoSharingSettings.twitterAccessTokenKey)
+            twitterSecret = QVariant(VideoSharingSettings.twitterAccessTokenSecret)
+            facebookAuthDialog = QVariant(VideoSharingSettings.raiseFacebookAuthorisationDialog)
+            facebookToken = QVariant(VideoSharingSettings.facebookAccessToken)
+            searchOrder = QVariant(SearchSettings.searchOrder)
+            recentSearches = QVariant(SearchSettings.recentSearches)
+            settings.setValue("autoOrientation", autoOrientation)
+            settings.setValue("userDict", userDict)
+            settings.setValue("defaultUser", defaultUser)
+            settings.setValue("noAccountDialog", noAccountDialog)
+            settings.setValue("downloadFolder", downloadFolder)
+            settings.setValue("downloadStatus", downloadStatus)
+            settings.setValue("playbackFormat", playbackFormat)
+            settings.setValue("downloadFormat", downloadFormat)
+            settings.setValue("downloadTaskQueue", downloadTaskQueue)
+            settings.setValue("twitterAuthDialog", twitterAuthDialog)
+            settings.setValue("twitterKey", twitterKey)
+            settings.setValue("twitterSecret", twitterSecret)
+            settings.setValue("facebookAuthDialog", facebookAuthDialog)
+            settings.setValue("facebookToken", facebookToken)
+            settings.setValue("searchOrder", searchOrder)
+            settings.setValue("recentSearches", recentSearches)
+            CutetubeLog.logInfo("Settings saved successfully")
+        except Exception, e:
+            CutetubeLog.logException("Unable to save settings:")
         
     def setAutoDisplayOrientation(self):
         """
@@ -289,9 +301,9 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
     @pyqtSignature("")
     def on_actionAbout_triggered(self):
         """
-        Raises an AboutDialog
+        Raises an AboutWindow
         """
-        aboutDialog = cutetubedialogs.AboutDialog(self)
+        aboutWindow = AboutWindow(self)
 
         
         
